@@ -13,9 +13,9 @@ from molsystem.system_db import SystemDB
 @pytest.fixture(scope="module")
 def configuration():
     """Create a system db, system and configuration."""
-    db = SystemDB(filename='file:seamm_db?mode=memory&cache=shared')
-    system = db.create_system(name='default')
-    configuration = system.create_configuration(name='default')
+    db = SystemDB(filename="file:seamm_db?mode=memory&cache=shared")
+    system = db.create_system(name="default")
+    configuration = system.create_configuration(name="default")
 
     yield configuration
 
@@ -23,10 +23,10 @@ def configuration():
     try:
         del db
     except:  # noqa: E722
-        print('Caught error deleting the database')
+        print("Caught error deleting the database")
 
 
-@pytest.mark.parametrize('file_name', [1, [], {}, 1.0])
+@pytest.mark.parametrize("file_name", [1, [], {}, 1.0])
 def test_read_filename_type(configuration, file_name):
 
     with pytest.raises(TypeError):
@@ -36,12 +36,12 @@ def test_read_filename_type(configuration, file_name):
 def test_empty_filename(configuration):
 
     with pytest.raises(NameError):
-        read_structure_step.read('', configuration)
+        read_structure_step.read("", configuration)
 
 
 def test_unregistered_reader(configuration):
 
     with pytest.raises(KeyError):
 
-        xyz_file = build_filenames.build_data_filename('spc.xyz')
-        read_structure_step.read(xyz_file, configuration, extension='.mp3')
+        xyz_file = build_filenames.build_data_filename("spc.xyz")
+        read_structure_step.read(xyz_file, configuration, extension=".mp3")
